RDMO - Research Data Management Organiser
=========================================

.. image:: https://travis-ci.org/rdmorganiser/rdmo.svg?branch=master
   :alt: Build Status
   :target: https://travis-ci.org/rdmorganiser/rdmo

.. image:: https://coveralls.io/repos/rdmorganiser/rdmo/badge.svg?branch=master&service=github
   :alt: Coverage Status
   :target: https://coveralls.io/github/rdmorganiser/rdmo?branch=master

.. image:: https://img.shields.io/pypi/v/rdmo.svg?style=flat
   :alt: Latest Version
   :target: https://pypi.python.org/pypi/rdmo/

.. image:: https://readthedocs.org/projects/rdmo/badge/?version=latest
   :alt: Documentation status
   :target: http://rdmo.readthedocs.io/en/latest/?badge=latest

.. image:: http://img.shields.io/badge/license-APACHE-blue.svg?style=flat
   :alt: License
   :target: https://github.com/rdmorganiser/rdmo/blob/master/LICENSE

.. image:: https://pyup.io/repos/github/rdmorganiser/rdmo/shield.svg
     :target: https://pyup.io/repos/github/rdmorganiser/rdmo/
     :alt: Updates

RDMO is a tool to support the systematic planning, organisation and implementation of the data management throughout the course of a research project. RDMO is funded by the Deutsche Forschungsgemeinschaft (DFG).

Home Page
  https://rdmorganiser.github.io

Source code
  https://github.com/rdmorganiser/rdmo

Documentation
  http://rdmo.readthedocs.io

Mailing list
  https://www.listserv.dfn.de/sympa/subscribe/rdmo

Slack
  https://rdmo.slack.com

Demo
  https://rdmo.aip.de
